.. _ref-API-Root:

Root class
==========

A root is a remote repository that can be subscribed to.

.. currentmodule:: caterva2
.. autosummary::
    :toctree: autofiles

    Root.__init__
    Root.__getitem__
    Root.__contains__
    Root.__iter__
    Root.__len__
    Root.file_list
    Root.upload
